import java.util.LinkedList;
import java.util.Queue;
import java.util.Scanner;

public class 迷宫问题 {

    private static final int ROWS = 5;
    private static final int COLS = 5;
    private static final int[][] DIRECTIONS = {{1, 0}, {-1, 0}, {0, 1}, {0, -1}}; // Right, Left, Down, Up  

    public static void main(String[] args) {
        Scanner scanner = new Scanner(System.in);
        int[][] maze = new int[ROWS][COLS];
        for (int i = 0; i < ROWS; i++) {
            String line = scanner.next();
            for (int j = 0; j < COLS; j++) {
                maze[i][j] = line.charAt(j) - '0';
            }
        }
        scanner.close();

        boolean[][] visited = new boolean[ROWS][COLS];
        Queue<int[]> path = new LinkedList<>();
        path.add(new int[]{0, 0}); // Start position  

        if (findPath(maze, visited, path)) {
            printPath(path);
        } else {
            System.out.println("No path found.");
        }
    }

    private static boolean findPath(int[][] maze, boolean[][] visited, Queue<int[]> path) {
        int[] current = path.peek();
        int row = current[0];
        int col = current[1];

        if (row == ROWS - 1 && col == COLS - 1) { // Reached the destination  
            return true;
        }

        visited[row][col] = true;

        for (int[] direction : DIRECTIONS) {
            int newRow = row + direction[0];
            int newCol = col + direction[1];

            if (newRow >= 0 && newRow < ROWS && newCol >= 0 && newCol < COLS && maze[newRow][newCol] == 0 && !visited[newRow][newCol]) {
                path.add(new int[]{newRow, newCol});
                if (findPath(maze, visited, path)) {
                    return true;
                }
                path.remove(); // Backtrack  
            }
        }

        return false;
    }

    private static void printPath(Queue<int[]> path) {
        while (!path.isEmpty()) {
            int[] position = path.poll();
            System.out.println("(" + position[0] + "," + position[1] + ")");
        }
    }
}